==> haskell-yesod-persistent-1.6.0.8-475-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-GbxYOR2HCDw5mSWSv7LbxG
key:                  yesod-persistent-1.6.0.8-GbxYOR2HCDw5mSWSv7LbxG
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  624189c0239b0cdb244ad84bbf4974c2
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-GbxYOR2HCDw5mSWSv7LbxG
depends:
    base-4.17.2.1 blaze-builder-0.4.4-1ntb6RP4OewIlLWEkSeIAR
    conduit-1.3.6.1-E440ekNNgW6K3EfLZREfa1
    persistent-2.14.5.2-GPWHCW8fdRqGAAF6p19mHm
    resource-pool-0.2.3.2-5oQsv6yyKmlCMdNDJD8QG7
    resourcet-1.2.6-KOK8YcGoRtO4DzojWOYtyP transformers-0.5.6.2
    yesod-core-1.6.27.1-KFoprkJXhJa2ewlge46soy

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-persistent-1.6.0.8-504-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-yesod-persistent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yesod-persistent
version:              1.6.0.8
visibility:           public
id:                   yesod-persistent-1.6.0.8-5LBIN6k6CwtDeQL9oX4i2b
key:                  yesod-persistent-1.6.0.8-5LBIN6k6CwtDeQL9oX4i2b
license:              MIT
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Stable
homepage:             http://www.yesodweb.com/
synopsis:             Some helpers for using Persistent from Yesod.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-persistent>

category:             Web, Yesod, Database
abi:                  96b46335d9be59a1beea5d105859d410
exposed:              True
exposed-modules:      Yesod.Persist Yesod.Persist.Core
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yesod-persistent-1.6.0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yesod-persistent
hs-libraries:         HSyesod-persistent-1.6.0.8-5LBIN6k6CwtDeQL9oX4i2b
depends:
    base-4.17.2.1 blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz
    conduit-1.3.6.1-YyCKRGvJ9RFx9ccf8Rnd3
    persistent-2.14.5.2-4XQ911owVSTIyWoNtMmSaI
    resource-pool-0.2.3.2-IwokjjpbTKCEUx26uJ9tBR
    resourcet-1.2.6-7JBHLKMrq1iCQRZHHoRMKl transformers-0.5.6.2
    yesod-core-1.6.27.1-EwsliX2Eq0V3h6VQF9toZp

haddock-interfaces:
    /usr/share/doc/haskell-yesod-persistent/html/yesod-persistent.haddock

haddock-html:         /usr/share/doc/haskell-yesod-persistent/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
